<?php
$page_title = "Admin Dashboard";
$extra_css = '
<link href="https://cdn.jsdelivr.net/npm/dropzone@5.9.3/dist/min/dropzone.min.css" rel="stylesheet">
<link href="https://cdn.jsdelivr.net/npm/chart.js@3.7.0/dist/chart.min.css" rel="stylesheet">
';
require_once 'header.php';
require_once 'database.php';

// Check if user is admin
if (!isset($_SESSION['role']) || $_SESSION['role'] !== 'admin') {
    header("Location: index.php");
    exit();
}

$db = new Database();
$conn = $db->connect();

$success_message = '';
$error_message = '';

// Get current settings
$settings = [];
$settings_query = $conn->query("SELECT setting_key, setting_value FROM system_settings");
while ($row = $settings_query->fetch()) {
    $settings[$row['setting_key']] = $row['setting_value'];
}

// Handle form submissions
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    if (isset($_POST['action'])) {
        switch ($_POST['action']) {
            case 'add_user':
                $username = trim($_POST['username']);
                $password = $_POST['password'];
                $role = $_POST['role'];
                
                try {
                    $stmt = $conn->prepare("SELECT id FROM users WHERE username = ?");
                    $stmt->execute([$username]);
                    if ($stmt->fetch()) {
                        $error_message = "Username already exists";
                    } else {
                        $hashed_password = password_hash($password, PASSWORD_DEFAULT);
                        $stmt = $conn->prepare("INSERT INTO users (username, password, role) VALUES (?, ?, ?)");
                        $stmt->execute([$username, $hashed_password, $role]);
                        
                        // Log activity
                        logUserActivity($_SESSION['user_id'], 'create_user', "Created new user: $username");
                        $success_message = "User added successfully";
                    }
                } catch (PDOException $e) {
                    $error_message = "Error adding user: " . $e->getMessage();
                }
                break;

            case 'delete_user':
                $user_id = $_POST['user_id'];
                if ($user_id != $_SESSION['user_id']) {
                    try {
                        $stmt = $conn->prepare("DELETE FROM users WHERE id = ?");
                        $stmt->execute([$user_id]);
                        logUserActivity($_SESSION['user_id'], 'delete_user', "Deleted user ID: $user_id");
                        $success_message = "User deleted successfully";
                    } catch (PDOException $e) {
                        $error_message = "Error deleting user: " . $e->getMessage();
                    }
                } else {
                    $error_message = "You cannot delete your own account";
                }
                break;

            case 'reset_password':
                $user_id = $_POST['user_id'];
                $new_password = $_POST['new_password'];
                try {
                    $hashed_password = password_hash($new_password, PASSWORD_DEFAULT);
                    $stmt = $conn->prepare("UPDATE users SET password = ? WHERE id = ?");
                    $stmt->execute([$hashed_password, $user_id]);
                    logUserActivity($_SESSION['user_id'], 'reset_password', "Reset password for user ID: $user_id");
                    $success_message = "Password reset successfully";
                } catch (PDOException $e) {
                    $error_message = "Error resetting password: " . $e->getMessage();
                }
                break;

            case 'add_product':
                $name = trim($_POST['name']);
                $price = floatval($_POST['price']);
                $category = $_POST['category'];
                $description = trim($_POST['description']);
                $quantity = intval($_POST['quantity']);
                $reorder_point = intval($_POST['reorder_point']);
                
                try {
                    $conn->beginTransaction();
                    
                    // Insert product
                    $stmt = $conn->prepare("INSERT INTO products (name, price, category, description) VALUES (?, ?, ?, ?)");
                    $stmt->execute([$name, $price, $category, $description]);
                    $product_id = $conn->lastInsertId();
                    
                    // Insert inventory
                    $stmt = $conn->prepare("INSERT INTO product_inventory (product_id, quantity, reorder_point) VALUES (?, ?, ?)");
                    $stmt->execute([$product_id, $quantity, $reorder_point]);
                    
                    $conn->commit();
                    logUserActivity($_SESSION['user_id'], 'add_product', "Added new product: $name");
                    $success_message = "Product added successfully";
                } catch (PDOException $e) {
                    $conn->rollBack();
                    $error_message = "Error adding product: " . $e->getMessage();
                }
                break;

            case 'delete_product':
                $product_id = $_POST['product_id'];
                try {
                    $stmt = $conn->prepare("DELETE FROM products WHERE id = ?");
                    $stmt->execute([$product_id]);
                    logUserActivity($_SESSION['user_id'], 'delete_product', "Deleted product ID: $product_id");
                    $success_message = "Product deleted successfully";
                } catch (PDOException $e) {
                    $error_message = "Error deleting product: " . $e->getMessage();
                }
                break;

            case 'update_settings':
                try {
                    foreach ($_POST['settings'] as $key => $value) {
                        $stmt = $conn->prepare("UPDATE system_settings SET setting_value = ? WHERE setting_key = ?");
                        $stmt->execute([$value, $key]);
                    }
                    logUserActivity($_SESSION['user_id'], 'update_settings', "Updated system settings");
                    $success_message = "Settings updated successfully";
                    
                    // Refresh settings
                    $settings_query = $conn->query("SELECT setting_key, setting_value FROM system_settings");
                    while ($row = $settings_query->fetch()) {
                        $settings[$row['setting_key']] = $row['setting_value'];
                    }
                } catch (PDOException $e) {
                    $error_message = "Error updating settings: " . $e->getMessage();
                }
                break;

            case 'update_order_status':
                $order_id = $_POST['order_id'];
                $table = $_POST['table'];
                $new_status = $_POST['status'];
                
                try {
                    $stmt = $conn->prepare("UPDATE $table SET status = ? WHERE id = ?");
                    $stmt->execute([$new_status, $order_id]);
                    logUserActivity($_SESSION['user_id'], 'update_order_status', "Updated order #$order_id status to $new_status in $table");
                    $success_message = "Order status updated successfully";
                } catch (PDOException $e) {
                    $error_message = "Error updating order status: " . $e->getMessage();
                }
                break;
        }
    }
}

// Function to log user activity
function logUserActivity($user_id, $action, $details) {
    global $conn;
    $ip = $_SERVER['REMOTE_ADDR'];
    $stmt = $conn->prepare("INSERT INTO user_activity_logs (user_id, action, details, ip_address) VALUES (?, ?, ?, ?)");
    $stmt->execute([$user_id, $action, $details, $ip]);
}

// Fetch all users
$users = $conn->query("SELECT id, username, role FROM users ORDER BY username")->fetchAll();

// Fetch all products with inventory
$products = $conn->query("
    SELECT p.*, pi.quantity, pi.reorder_point 
    FROM products p 
    LEFT JOIN product_inventory pi ON p.id = pi.product_id 
    ORDER BY p.category, p.name
")->fetchAll();

// Get recent activity logs
$activity_logs = $conn->query("
    SELECT l.*, u.username 
    FROM user_activity_logs l 
    JOIN users u ON l.user_id = u.id 
    ORDER BY l.created_at DESC 
    LIMIT 10
")->fetchAll();

// Get security logs
$security_logs = $conn->query("
    SELECT * FROM security_logs 
    ORDER BY created_at DESC 
    LIMIT 10
")->fetchAll();

// Get basic statistics
$stats = [
    'total_users' => $conn->query("SELECT COUNT(*) FROM users")->fetchColumn(),
    'total_products' => $conn->query("SELECT COUNT(*) FROM products")->fetchColumn(),
    'total_orders' => $conn->query("SELECT (SELECT COUNT(*) FROM canva) + (SELECT COUNT(*) FROM pack) + (SELECT COUNT(*) FROM office) as total")->fetchColumn(),
    'total_revenue' => $conn->query("SELECT COALESCE(SUM(prix), 0) FROM (SELECT prix FROM canva UNION ALL SELECT prix FROM pack UNION ALL SELECT prix FROM office) as all_orders")->fetchColumn(),
    'low_stock' => $conn->query("SELECT COUNT(*) FROM product_inventory WHERE quantity <= reorder_point")->fetchColumn()
];

// Get sales data for chart
$sales_data = $conn->query("
    SELECT 
        DATE(date) as sale_date,
        COUNT(*) as order_count,
        SUM(prix) as revenue
    FROM (
        SELECT date, prix FROM canva
        UNION ALL
        SELECT date, prix FROM pack
        UNION ALL
        SELECT date, prix FROM office
    ) all_orders
    WHERE date >= DATE_SUB(CURRENT_DATE, INTERVAL 30 DAY)
    GROUP BY DATE(date)
    ORDER BY sale_date
")->fetchAll();

// Get recent orders from all tables
$recent_orders = $conn->query("
    SELECT 
        'canva' as source,
        id,
        date,
        phone,
        email,
        bank,
        prix as amount,
        COALESCE(status, 'pending') as status
    FROM canva
    UNION ALL
    SELECT 
        'pack' as source,
        id,
        date,
        phone,
        email,
        bank,
        prix as amount,
        COALESCE(status, 'pending') as status
    FROM pack
    UNION ALL
    SELECT 
        'office' as source,
        id,
        date,
        phone,
        email,
        bank,
        prix as amount,
        COALESCE(status, 'pending') as status
    FROM office
    ORDER BY date DESC
    LIMIT 50
")->fetchAll();
?>

    <!-- Statistics Cards -->
    <div class="row g-4 mb-4">
        <div class="col-md-3">
            <div class="card">
                <div class="card-body">
                    <h6 class="card-title text-muted">Total Users</h6>
                    <h3><?php echo number_format($stats['total_users']); ?></h3>
                </div>
            </div>
        </div>
        <div class="col-md-3">
            <div class="card">
                <div class="card-body">
                    <h6 class="card-title text-muted">Total Products</h6>
                    <h3><?php echo number_format($stats['total_products']); ?></h3>
                </div>
            </div>
        </div>
        <div class="col-md-3">
            <div class="card">
                <div class="card-body">
                    <h6 class="card-title text-muted">Total Orders</h6>
                    <h3><?php echo number_format($stats['total_orders']); ?></h3>
                    <a href="orders.php" class="btn btn-sm btn-primary mt-2">Manage Orders</a>
                </div>
            </div>
        </div>
        <div class="col-md-3">
            <div class="card">
                <div class="card-body">
                    <h6 class="card-title text-muted">Total Revenue</h6>
                    <h3>$<?php echo number_format($stats['total_revenue'], 2); ?></h3>
                </div>
            </div>
        </div>
    </div>

    <?php if ($success_message): ?>
        <div class="alert alert-success"><?php echo htmlspecialchars($success_message); ?></div>
    <?php endif; ?>

    <?php if ($error_message): ?>
        <div class="alert alert-danger"><?php echo htmlspecialchars($error_message); ?></div>
    <?php endif; ?>

    <!-- Sales Chart -->
    <div class="card mb-4">
        <div class="card-body">
            <h5 class="card-title">Sales Overview</h5>
            <canvas id="salesChart" height="100"></canvas>
        </div>
    </div>

    <div class="row">
        <!-- User Management -->
        <div class="col-md-6 mb-4">
            <div class="card">
                <div class="card-body">
                    <h5 class="card-title">User Management</h5>
                    
                    <!-- Add User Form -->
                    <form method="POST" class="mb-4">
                        <input type="hidden" name="action" value="add_user">
                        <div class="mb-3">
                            <label class="form-label">Username</label>
                            <input type="text" name="username" class="form-control" required>
                        </div>
                        <div class="mb-3">
                            <label class="form-label">Password</label>
                            <input type="password" name="password" class="form-control" required>
                        </div>
                        <div class="mb-3">
                            <label class="form-label">Role</label>
                            <select name="role" class="form-select" required>
                                <option value="user">User</option>
                                <option value="admin">Admin</option>
                            </select>
                        </div>
                        <button type="submit" class="btn btn-primary">Add User</button>
                    </form>

                    <!-- Users List -->
                    <div class="table-responsive">
                        <table class="table">
                            <thead>
                                <tr>
                                    <th>Username</th>
                                    <th>Role</th>
                                    <th>Actions</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($users as $user): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($user['username']); ?></td>
                                    <td><?php echo htmlspecialchars($user['role']); ?></td>
                                    <td>
                                        <?php if ($user['id'] != $_SESSION['user_id']): ?>
                                        <button type="button" class="btn btn-warning btn-sm" data-bs-toggle="modal" data-bs-target="#resetPassword<?php echo $user['id']; ?>">
                                            Reset Password
                                        </button>
                                        <form method="POST" style="display: inline;">
                                            <input type="hidden" name="action" value="delete_user">
                                            <input type="hidden" name="user_id" value="<?php echo $user['id']; ?>">
                                            <button type="submit" class="btn btn-danger btn-sm" onclick="return confirm('Are you sure you want to delete this user?')">Delete</button>
                                        </form>
                                        
                                        <!-- Reset Password Modal -->
                                        <div class="modal fade" id="resetPassword<?php echo $user['id']; ?>" tabindex="-1">
                                            <div class="modal-dialog">
                                                <div class="modal-content">
                                                    <div class="modal-header">
                                                        <h5 class="modal-title">Reset Password for <?php echo htmlspecialchars($user['username']); ?></h5>
                                                        <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                                                    </div>
                                                    <form method="POST">
                                                        <div class="modal-body">
                                                            <input type="hidden" name="action" value="reset_password">
                                                            <input type="hidden" name="user_id" value="<?php echo $user['id']; ?>">
                                                            <div class="mb-3">
                                                                <label class="form-label">New Password</label>
                                                                <input type="password" name="new_password" class="form-control" required>
                                                            </div>
                                                        </div>
                                                        <div class="modal-footer">
                                                            <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                                                            <button type="submit" class="btn btn-primary">Reset Password</button>
                                                        </div>
                                                    </form>
                                                </div>
                                            </div>
                                        </div>
                                        <?php endif; ?>
                                    </td>
                                </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>

            <!-- Activity Logs -->
            <div class="card mt-4">
                <div class="card-body">
                    <h5 class="card-title">Recent Activity</h5>
                    <div class="table-responsive">
                        <table class="table">
                            <thead>
                                <tr>
                                    <th>User</th>
                                    <th>Action</th>
                                    <th>Details</th>
                                    <th>Date</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($activity_logs as $log): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($log['username']); ?></td>
                                    <td><?php echo htmlspecialchars($log['action']); ?></td>
                                    <td><?php echo htmlspecialchars($log['details']); ?></td>
                                    <td><?php echo date('Y-m-d H:i:s', strtotime($log['created_at'])); ?></td>
                                </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>

        <!-- Product Management -->
        <div class="col-md-6 mb-4">
            <div class="card">
                <div class="card-body">
                    <h5 class="card-title">Product Management</h5>
                    
                    <!-- Add Product Form -->
                    <form method="POST" class="mb-4">
                        <input type="hidden" name="action" value="add_product">
                        <div class="mb-3">
                            <label class="form-label">Product Name</label>
                            <input type="text" name="name" class="form-control" required>
                        </div>
                        <div class="mb-3">
                            <label class="form-label">Price</label>
                            <input type="number" name="price" class="form-control" step="0.01" required>
                        </div>
                        <div class="mb-3">
                            <label class="form-label">Category</label>
                            <select name="category" class="form-select" required>
                                <option value="canva">Canva</option>
                                <option value="pack">Pack</option>
                                <option value="office">Office</option>
                            </select>
                        </div>
                        <div class="mb-3">
                            <label class="form-label">Description</label>
                            <textarea name="description" class="form-control" rows="3"></textarea>
                        </div>
                        <div class="mb-3">
                            <label class="form-label">Initial Stock Quantity</label>
                            <input type="number" name="quantity" class="form-control" value="0" required>
                        </div>
                        <div class="mb-3">
                            <label class="form-label">Reorder Point</label>
                            <input type="number" name="reorder_point" class="form-control" value="10" required>
                        </div>
                        <button type="submit" class="btn btn-primary">Add Product</button>
                    </form>

                    <!-- Products List -->
                    <div class="table-responsive">
                        <table class="table">
                            <thead>
                                <tr>
                                    <th>Name</th>
                                    <th>Category</th>
                                    <th>Price</th>
                                    <th>Stock</th>
                                    <th>Actions</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($products as $product): ?>
                                <tr class="<?php echo $product['quantity'] <= $product['reorder_point'] ? 'table-warning' : ''; ?>">
                                    <td><?php echo htmlspecialchars($product['name']); ?></td>
                                    <td><?php echo htmlspecialchars($product['category']); ?></td>
                                    <td>$<?php echo number_format($product['price'], 2); ?></td>
                                    <td>
                                        <?php echo number_format($product['quantity']); ?>
                                        <?php if ($product['quantity'] <= $product['reorder_point']): ?>
                                            <span class="badge bg-warning">Low Stock</span>
                                        <?php endif; ?>
                                    </td>
                                    <td>
                                        <button type="button" class="btn btn-info btn-sm" data-bs-toggle="modal" data-bs-target="#editProduct<?php echo $product['id']; ?>">
                                            Edit
                                        </button>
                                        <form method="POST" style="display: inline;">
                                            <input type="hidden" name="action" value="delete_product">
                                            <input type="hidden" name="product_id" value="<?php echo $product['id']; ?>">
                                            <button type="submit" class="btn btn-danger btn-sm" onclick="return confirm('Are you sure you want to delete this product?')">Delete</button>
                                        </form>
                                    </td>
                                </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>

            <!-- System Settings -->
            <div class="card mt-4">
                <div class="card-body">
                    <h5 class="card-title">System Settings</h5>
                    <form method="POST">
                        <input type="hidden" name="action" value="update_settings">
                        <div class="row">
                            <div class="col-md-6 mb-3">
                                <label class="form-label">Site Name</label>
                                <input type="text" name="settings[site_name]" class="form-control" value="<?php echo htmlspecialchars($settings['site_name']); ?>">
                            </div>
                            <div class="col-md-6 mb-3">
                                <label class="form-label">Admin Email</label>
                                <input type="email" name="settings[admin_email]" class="form-control" value="<?php echo htmlspecialchars($settings['admin_email']); ?>">
                            </div>
                            <div class="col-md-6 mb-3">
                                <label class="form-label">Enable 2FA</label>
                                <select name="settings[enable_2fa]" class="form-select">
                                    <option value="0" <?php echo $settings['enable_2fa'] == '0' ? 'selected' : ''; ?>>Disabled</option>
                                    <option value="1" <?php echo $settings['enable_2fa'] == '1' ? 'selected' : ''; ?>>Enabled</option>
                                </select>
                            </div>
                            <div class="col-md-6 mb-3">
                                <label class="form-label">Max Login Attempts</label>
                                <input type="number" name="settings[max_login_attempts]" class="form-control" value="<?php echo htmlspecialchars($settings['max_login_attempts']); ?>">
                            </div>
                            <div class="col-md-6 mb-3">
                                <label class="form-label">Currency</label>
                                <input type="text" name="settings[currency]" class="form-control" value="<?php echo htmlspecialchars($settings['currency']); ?>">
                            </div>
                            <div class="col-md-6 mb-3">
                                <label class="form-label">Items Per Page</label>
                                <input type="number" name="settings[items_per_page]" class="form-control" value="<?php echo htmlspecialchars($settings['items_per_page']); ?>">
                            </div>
                        </div>
                        <button type="submit" class="btn btn-primary">Save Settings</button>
                    </form>
                </div>
            </div>

            <!-- Security Logs -->
            <div class="card mt-4">
                <div class="card-body">
                    <h5 class="card-title">Security Logs</h5>
                    <div class="table-responsive">
                        <table class="table">
                            <thead>
                                <tr>
                                    <th>Type</th>
                                    <th>Status</th>
                                    <th>Username</th>
                                    <th>IP Address</th>
                                    <th>Date</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($security_logs as $log): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($log['type']); ?></td>
                                    <td>
                                        <span class="badge bg-<?php echo $log['status'] === 'success' ? 'success' : 'danger'; ?>">
                                            <?php echo htmlspecialchars($log['status']); ?>
                                        </span>
                                    </td>
                                    <td><?php echo htmlspecialchars($log['username']); ?></td>
                                    <td><?php echo htmlspecialchars($log['ip_address']); ?></td>
                                    <td><?php echo date('Y-m-d H:i:s', strtotime($log['created_at'])); ?></td>
                                </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<script>
// Sales Chart
const salesCtx = document.getElementById('salesChart').getContext('2d');
const salesData = <?php echo json_encode(array_column($sales_data, 'revenue')); ?>;
const orderData = <?php echo json_encode(array_column($sales_data, 'order_count')); ?>;
const salesLabels = <?php echo json_encode(array_column($sales_data, 'sale_date')); ?>;

new Chart(salesCtx, {
    type: 'line',
    data: {
        labels: salesLabels,
        datasets: [
            {
                label: 'Revenue ($)',
                data: salesData,
                borderColor: '#0d6efd',
                yAxisID: 'y'
            },
            {
                label: 'Orders',
                data: orderData,
                borderColor: '#198754',
                yAxisID: 'y1'
            }
        ]
    },
    options: {
        responsive: true,
        interaction: {
            mode: 'index',
            intersect: false,
        },
        scales: {
            y: {
                type: 'linear',
                display: true,
                position: 'left',
                title: {
                    display: true,
                    text: 'Revenue ($)'
                }
            },
            y1: {
                type: 'linear',
                display: true,
                position: 'right',
                grid: {
                    drawOnChartArea: false,
                },
                title: {
                    display: true,
                    text: 'Number of Orders'
                }
            }
        }
    }
});
</script>
</body>
</html> 