<?php
$page_title = "Analytics Dashboard";
$extra_css = '
<link href="https://cdn.jsdelivr.net/npm/daterangepicker/daterangepicker.css" rel="stylesheet">
<link href="https://cdn.jsdelivr.net/npm/chart.js@3.7.0/dist/chart.min.css" rel="stylesheet">
';
require_once 'header.php';
require_once 'database.php';

// Check if user is logged in
if (!isset($_SESSION['user_id'])) {
    header("Location: login.php");
    exit();
}

$db = new Database();
$conn = $db->connect();

// Get filter parameters
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d', strtotime('-30 days'));
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');
$source = isset($_GET['source']) ? $_GET['source'] : 'all';
$bank = isset($_GET['bank']) ? $_GET['bank'] : 'all';
$status = isset($_GET['status']) ? $_GET['status'] : 'all';

// Build the WHERE clause based on filters
$where_conditions = ["co.date BETWEEN :start_date AND :end_date"];
if ($source !== 'all') $where_conditions[] = "co.source = :source";
if ($bank !== 'all') $where_conditions[] = "co.bank = :bank";
if ($status !== 'all') $where_conditions[] = "co.status = :status";

$where_clause = implode(" AND ", $where_conditions);

// Get unique banks for filter
$banks = $conn->query("SELECT DISTINCT bank FROM combined_orders WHERE bank IS NOT NULL ORDER BY bank")->fetchAll(PDO::FETCH_COLUMN);

// Get summary statistics
$stmt = $conn->prepare("
    SELECT 
        COUNT(*) as total_orders,
        SUM(co.amount) as total_revenue,
        SUM(co.cost) + COALESCE((
            SELECT SUM(amount_spent)
            FROM fb_ads
            WHERE date BETWEEN :start_date AND :end_date
        ), 0) as total_cost,
        SUM(co.amount) - (SUM(co.cost) + COALESCE((
            SELECT SUM(amount_spent)
            FROM fb_ads
            WHERE date BETWEEN :start_date AND :end_date
        ), 0)) as total_profit,
        COUNT(CASE WHEN co.confirmed = 1 THEN 1 END) as confirmed_orders,
        AVG(co.amount) as avg_order_value
    FROM combined_orders co
    WHERE $where_clause
");

$params = [':start_date' => $start_date, ':end_date' => $end_date];
if ($source !== 'all') $params[':source'] = $source;
if ($bank !== 'all') $params[':bank'] = $bank;
if ($status !== 'all') $params[':status'] = $status;

$stmt->execute($params);
$summary = $stmt->fetch(PDO::FETCH_ASSOC);

// Get revenue by source
$stmt = $conn->prepare("
    WITH fb_costs AS (
        SELECT SUM(amount_spent) as fb_spend
        FROM fb_ads
        WHERE date BETWEEN :start_date AND :end_date
    )
    SELECT 
        co.source,
        COUNT(*) as order_count,
        SUM(co.amount) as total_revenue,
        CASE 
            WHEN co.source = 'canva' THEN SUM(co.cost) + COALESCE((SELECT fb_spend FROM fb_costs), 0)
            ELSE SUM(co.cost)
        END as total_cost,
        CASE 
            WHEN co.source = 'canva' THEN SUM(co.amount) - (SUM(co.cost) + COALESCE((SELECT fb_spend FROM fb_costs), 0))
            ELSE SUM(co.amount) - SUM(co.cost)
        END as total_profit
    FROM combined_orders co
    WHERE $where_clause
    GROUP BY co.source
");
$stmt->execute($params);
$revenue_by_source = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Get revenue by bank
$stmt = $conn->prepare("
    SELECT 
        co.bank,
        COUNT(*) as order_count,
        SUM(co.amount) as total_revenue
    FROM combined_orders co
    WHERE $where_clause AND co.bank IS NOT NULL
    GROUP BY co.bank
    ORDER BY total_revenue DESC
");
$stmt->execute($params);
$revenue_by_bank = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Get daily revenue trend
$stmt = $conn->prepare("
    SELECT 
        DATE(co.date) as sale_date,
        COUNT(*) as order_count,
        SUM(co.amount) as revenue,
        SUM(co.cost) + COALESCE(SUM(fa.amount_spent), 0) as cost,
        SUM(co.amount) - (SUM(co.cost) + COALESCE(SUM(fa.amount_spent), 0)) as profit
    FROM combined_orders co
    LEFT JOIN fb_ads fa ON DATE(co.date) = DATE(fa.date)
    WHERE $where_clause
    GROUP BY DATE(co.date)
    ORDER BY sale_date
");
$stmt->execute($params);
$daily_trend = $stmt->fetchAll(PDO::FETCH_ASSOC);
?>

<div class="container-fluid px-4">
    <h1 class="mt-4">Analytics Dashboard</h1>
    
    <!-- Filters -->
    <div class="card mb-4">
        <div class="card-body">
            <form method="GET" class="row g-3">
                <div class="col-md-3">
                    <label class="form-label">Date Range</label>
                    <input type="text" id="daterange" name="daterange" class="form-control" 
                           value="<?php echo date('m/d/Y', strtotime($start_date)) . ' - ' . date('m/d/Y', strtotime($end_date)); ?>">
                    <input type="hidden" name="start_date" id="start_date" value="<?php echo $start_date; ?>">
                    <input type="hidden" name="end_date" id="end_date" value="<?php echo $end_date; ?>">
                </div>
                <div class="col-md-2">
                    <label class="form-label">Source</label>
                    <select name="source" class="form-select">
                        <option value="all" <?php echo $source === 'all' ? 'selected' : ''; ?>>All Sources</option>
                        <option value="canva" <?php echo $source === 'canva' ? 'selected' : ''; ?>>Canva</option>
                        <option value="pack" <?php echo $source === 'pack' ? 'selected' : ''; ?>>Pack</option>
                        <option value="office" <?php echo $source === 'office' ? 'selected' : ''; ?>>Office</option>
                    </select>
                </div>
                <div class="col-md-2">
                    <label class="form-label">Bank</label>
                    <select name="bank" class="form-select">
                        <option value="all">All Banks</option>
                        <?php foreach ($banks as $b): ?>
                            <option value="<?php echo htmlspecialchars($b); ?>" <?php echo $bank === $b ? 'selected' : ''; ?>>
                                <?php echo htmlspecialchars($b); ?>
                            </option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div class="col-md-2">
                    <label class="form-label">Status</label>
                    <select name="status" class="form-select">
                        <option value="all" <?php echo $status === 'all' ? 'selected' : ''; ?>>All Statuses</option>
                        <option value="pending" <?php echo $status === 'pending' ? 'selected' : ''; ?>>Pending</option>
                        <option value="processing" <?php echo $status === 'processing' ? 'selected' : ''; ?>>Processing</option>
                        <option value="completed" <?php echo $status === 'completed' ? 'selected' : ''; ?>>Completed</option>
                        <option value="cancelled" <?php echo $status === 'cancelled' ? 'selected' : ''; ?>>Cancelled</option>
                    </select>
                </div>
                <div class="col-md-2">
                    <label class="form-label">&nbsp;</label>
                    <button type="submit" class="btn btn-primary d-block">Apply Filters</button>
                </div>
            </form>
        </div>
    </div>

    <!-- Summary Cards -->
    <div class="row g-4 mb-4">
        <div class="col-xl-3 col-md-6">
            <div class="card">
                <div class="card-body">
                    <h6 class="card-title text-muted">Total Orders</h6>
                    <h3><?php echo number_format($summary['total_orders']); ?></h3>
                    <p class="text-muted mb-0">
                        <?php echo number_format($summary['confirmed_orders']); ?> confirmed
                    </p>
                </div>
            </div>
        </div>
        <div class="col-xl-3 col-md-6">
            <div class="card">
                <div class="card-body">
                    <h6 class="card-title text-muted">Total Revenue</h6>
                    <h3>$<?php echo number_format($summary['total_revenue'], 2); ?></h3>
                    <p class="text-muted mb-0">
                        Avg. $<?php echo number_format($summary['avg_order_value'], 2); ?> per order
                    </p>
                </div>
            </div>
        </div>
        <div class="col-xl-3 col-md-6">
            <div class="card">
                <div class="card-body">
                    <h6 class="card-title text-muted">Total Cost</h6>
                    <h3>$<?php echo number_format($summary['total_cost'], 2); ?></h3>
                    <p class="text-muted mb-0">
                        <?php 
                        $cost_percentage = $summary['total_revenue'] > 0 
                            ? ($summary['total_cost'] / $summary['total_revenue'] * 100) 
                            : 0;
                        echo number_format($cost_percentage, 1) . '% of revenue';
                        ?>
                    </p>
                </div>
            </div>
        </div>
        <div class="col-xl-3 col-md-6">
            <div class="card">
                <div class="card-body">
                    <h6 class="card-title text-muted">Total Profit</h6>
                    <h3>$<?php echo number_format($summary['total_profit'], 2); ?></h3>
                    <p class="text-muted mb-0">
                        <?php 
                        $profit_margin = $summary['total_revenue'] > 0 
                            ? ($summary['total_profit'] / $summary['total_revenue'] * 100) 
                            : 0;
                        echo number_format($profit_margin, 1) . '% margin';
                        ?>
                    </p>
                </div>
            </div>
        </div>
    </div>

    <div class="row">
        <!-- Revenue Trend Chart -->
        <div class="col-xl-8 col-lg-7">
            <div class="card mb-4">
                <div class="card-body">
                    <h5 class="card-title">Revenue Trend</h5>
                    <canvas id="revenueTrendChart" height="300"></canvas>
                </div>
            </div>
        </div>

        <!-- Revenue by Source -->
        <div class="col-xl-4 col-lg-5">
            <div class="card mb-4">
                <div class="card-body">
                    <h5 class="card-title">Revenue by Source</h5>
                    <canvas id="revenueBySourceChart" height="300"></canvas>
                </div>
            </div>
        </div>
    </div>

    <div class="row">
        <!-- Revenue by Bank -->
        <div class="col-lg-6">
            <div class="card mb-4">
                <div class="card-body">
                    <h5 class="card-title">Revenue by Bank</h5>
                    <div class="table-responsive">
                        <table class="table">
                            <thead>
                                <tr>
                                    <th>Bank</th>
                                    <th>Orders</th>
                                    <th>Revenue</th>
                                    <th>% of Total</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($revenue_by_bank as $bank_data): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($bank_data['bank']); ?></td>
                                    <td><?php echo number_format($bank_data['order_count']); ?></td>
                                    <td>$<?php echo number_format($bank_data['total_revenue'], 2); ?></td>
                                    <td>
                                        <?php 
                                        $percentage = $summary['total_revenue'] > 0 
                                            ? ($bank_data['total_revenue'] / $summary['total_revenue'] * 100) 
                                            : 0;
                                        echo number_format($percentage, 1) . '%';
                                        ?>
                                    </td>
                                </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>

        <!-- Revenue by Source Details -->
        <div class="col-lg-6">
            <div class="card mb-4">
                <div class="card-body">
                    <h5 class="card-title">Source Performance</h5>
                    <div class="table-responsive">
                        <table class="table">
                            <thead>
                                <tr>
                                    <th>Source</th>
                                    <th>Orders</th>
                                    <th>Revenue</th>
                                    <th>Cost</th>
                                    <th>Profit</th>
                                    <th>Margin</th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($revenue_by_source as $source_data): ?>
                                <tr>
                                    <td><?php echo ucfirst(htmlspecialchars($source_data['source'])); ?></td>
                                    <td><?php echo number_format($source_data['order_count']); ?></td>
                                    <td>$<?php echo number_format($source_data['total_revenue'], 2); ?></td>
                                    <td>$<?php echo number_format($source_data['total_cost'], 2); ?></td>
                                    <td>$<?php echo number_format($source_data['total_profit'], 2); ?></td>
                                    <td>
                                        <?php 
                                        $margin = $source_data['total_revenue'] > 0 
                                            ? ($source_data['total_profit'] / $source_data['total_revenue'] * 100) 
                                            : 0;
                                        echo number_format($margin, 1) . '%';
                                        ?>
                                    </td>
                                </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Page Specific Scripts -->
<script src="https://cdn.jsdelivr.net/npm/moment/moment.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/daterangepicker/daterangepicker.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>

<script>
document.addEventListener('DOMContentLoaded', function() {
    // Initialize date range picker
    $('#daterange').daterangepicker({
        startDate: moment('<?php echo $start_date; ?>'),
        endDate: moment('<?php echo $end_date; ?>'),
        ranges: {
           'Today': [moment(), moment()],
           'Yesterday': [moment().subtract(1, 'days'), moment().subtract(1, 'days')],
           'Last 7 Days': [moment().subtract(6, 'days'), moment()],
           'Last 30 Days': [moment().subtract(29, 'days'), moment()],
           'This Month': [moment().startOf('month'), moment().endOf('month')],
           'Last Month': [moment().subtract(1, 'month').startOf('month'), moment().subtract(1, 'month').endOf('month')]
        }
    }, function(start, end) {
        $('#start_date').val(start.format('YYYY-MM-DD'));
        $('#end_date').val(end.format('YYYY-MM-DD'));
    });

    // Revenue Trend Chart
    const trendCtx = document.getElementById('revenueTrendChart').getContext('2d');
    const trendData = <?php echo json_encode(array_column($daily_trend, 'revenue')); ?>;
    const trendLabels = <?php echo json_encode(array_column($daily_trend, 'sale_date')); ?>;
    const profitData = <?php echo json_encode(array_column($daily_trend, 'profit')); ?>;
    const orderCountData = <?php echo json_encode(array_column($daily_trend, 'order_count')); ?>;

    new Chart(trendCtx, {
        type: 'line',
        data: {
            labels: trendLabels,
            datasets: [
                {
                    label: 'Revenue',
                    data: trendData,
                    borderColor: '#0d6efd',
                    yAxisID: 'y'
                },
                {
                    label: 'Profit',
                    data: profitData,
                    borderColor: '#198754',
                    yAxisID: 'y'
                },
                {
                    label: 'Orders',
                    data: orderCountData,
                    borderColor: '#6c757d',
                    yAxisID: 'y1'
                }
            ]
        },
        options: {
            responsive: true,
            interaction: {
                mode: 'index',
                intersect: false,
            },
            scales: {
                y: {
                    type: 'linear',
                    display: true,
                    position: 'left',
                    title: {
                        display: true,
                        text: 'Amount ($)'
                    }
                },
                y1: {
                    type: 'linear',
                    display: true,
                    position: 'right',
                    grid: {
                        drawOnChartArea: false,
                    },
                    title: {
                        display: true,
                        text: 'Number of Orders'
                    }
                }
            }
        }
    });

    // Revenue by Source Chart
    const sourceCtx = document.getElementById('revenueBySourceChart').getContext('2d');
    const sourceData = <?php echo json_encode(array_column($revenue_by_source, 'total_revenue')); ?>;
    const sourceLabels = <?php echo json_encode(array_map('ucfirst', array_column($revenue_by_source, 'source'))); ?>;

    new Chart(sourceCtx, {
        type: 'doughnut',
        data: {
            labels: sourceLabels,
            datasets: [{
                data: sourceData,
                backgroundColor: ['#0d6efd', '#198754', '#ffc107']
            }]
        },
        options: {
            responsive: true,
            plugins: {
                legend: {
                    position: 'bottom'
                }
            }
        }
    });
});
</script>
</body>
</html> 