<?php
require_once 'header.php';
require_once 'database.php';

// Check if user is admin
if (!isset($_SESSION['role']) || $_SESSION['role'] !== 'admin') {
    header("Location: index.php");
    exit();
}

$db = new Database();
$conn = $db->connect();

// Get date range from request or default to last 30 days
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d', strtotime('-30 days'));
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');

// Fetch daily data with FB Ads costs
$query = "
    SELECT 
        DATE(o.date) as date,
        SUM(CASE WHEN o.source = 'canva' THEN o.prix ELSE 0 END) as canva_revenue,
        SUM(CASE WHEN o.source = 'pack' THEN o.prix ELSE 0 END) as pack_revenue,
        SUM(CASE WHEN o.source = 'office' THEN o.prix ELSE 0 END) as office_revenue,
        SUM(o.cost) as total_cost,
        SUM(CASE 
            WHEN o.source = 'canva' AND f.campaign_name LIKE '%canva%' THEN f.amount_spent
            WHEN o.source = 'pack' AND f.campaign_name LIKE '%pack%' THEN f.amount_spent
            WHEN o.source = 'office' AND f.campaign_name LIKE '%office%' THEN f.amount_spent
            ELSE 0 
        END) as fb_ads_cost
    FROM (
        SELECT date, 'canva' as source, prix, cost FROM canva
        UNION ALL
        SELECT date, 'pack' as source, prix, cost FROM pack
        UNION ALL
        SELECT date, 'office' as source, prix, cost FROM office
    ) as o
    LEFT JOIN fb_ads f ON DATE(o.date) = DATE(f.date)
    WHERE DATE(o.date) BETWEEN :start_date AND :end_date
    GROUP BY DATE(o.date)
    ORDER BY o.date DESC
";

$stmt = $conn->prepare($query);
$stmt->execute(['start_date' => $start_date, 'end_date' => $end_date]);
$daily_data = $stmt->fetchAll(PDO::FETCH_ASSOC);

// Prepare data for charts
$dates = array_column($daily_data, 'date');
$total_revenue = array_map(function($row) {
    return $row['canva_revenue'] + $row['pack_revenue'] + $row['office_revenue'];
}, $daily_data);
$total_cost = array_map(function($row) {
    return $row['total_cost'] + $row['fb_ads_cost'];
}, $daily_data);
$profit = array_map(function($row) {
    return ($row['canva_revenue'] + $row['pack_revenue'] + $row['office_revenue']) - 
           ($row['total_cost'] + $row['fb_ads_cost']);
}, $daily_data);
?>

<div class="container-fluid px-4">
    <h1 class="mt-4">Daily Analytics</h1>
    
    <!-- Date Range Picker -->
    <div class="card mb-4">
        <div class="card-body">
            <form method="GET" class="row g-3">
                <div class="col-md-4">
                    <label for="start_date" class="form-label">Start Date</label>
                    <input type="date" class="form-control" id="start_date" name="start_date" 
                           value="<?php echo htmlspecialchars($start_date); ?>">
                </div>
                <div class="col-md-4">
                    <label for="end_date" class="form-label">End Date</label>
                    <input type="date" class="form-control" id="end_date" name="end_date" 
                           value="<?php echo htmlspecialchars($end_date); ?>">
                </div>
                <div class="col-md-4 d-flex align-items-end">
                    <button type="submit" class="btn btn-primary">Update Range</button>
                </div>
            </form>
        </div>
    </div>

    <!-- Summary Cards -->
    <div class="row mb-4">
        <div class="col-xl-3 col-md-6">
            <div class="card bg-primary text-white mb-4">
                <div class="card-body">
                    <h5>Total Revenue</h5>
                    <h3><?php echo number_format(array_sum($total_revenue), 2); ?> MAD</h3>
                </div>
            </div>
        </div>
        <div class="col-xl-3 col-md-6">
            <div class="card bg-danger text-white mb-4">
                <div class="card-body">
                    <h5>Total Cost</h5>
                    <h3><?php echo number_format(array_sum($total_cost), 2); ?> MAD</h3>
                </div>
            </div>
        </div>
        <div class="col-xl-3 col-md-6">
            <div class="card bg-success text-white mb-4">
                <div class="card-body">
                    <h5>Total Profit</h5>
                    <h3><?php echo number_format(array_sum($profit), 2); ?> MAD</h3>
                </div>
            </div>
        </div>
        <div class="col-xl-3 col-md-6">
            <div class="card bg-info text-white mb-4">
                <div class="card-body">
                    <h5>Profit Margin</h5>
                    <h3><?php 
                        $total_rev = array_sum($total_revenue);
                        $total_cost = array_sum($total_cost);
                        echo $total_rev > 0 ? number_format(($total_rev - $total_cost) / $total_rev * 100, 1) : 0;
                    ?>%</h3>
                </div>
            </div>
        </div>
    </div>

    <!-- Charts -->
    <div class="row">
        <div class="col-xl-6">
            <div class="card mb-4">
                <div class="card-header">
                    <i class="fas fa-chart-line me-1"></i>
                    Daily Revenue vs Cost
                </div>
                <div class="card-body">
                    <canvas id="revenueCostChart" width="100%" height="40"></canvas>
                </div>
            </div>
        </div>
        <div class="col-xl-6">
            <div class="card mb-4">
                <div class="card-header">
                    <i class="fas fa-chart-bar me-1"></i>
                    Daily Profit
                </div>
                <div class="card-body">
                    <canvas id="profitChart" width="100%" height="40"></canvas>
                </div>
            </div>
        </div>
    </div>

    <!-- Detailed Table -->
    <div class="card mb-4">
        <div class="card-header">
            <i class="fas fa-table me-1"></i>
            Daily Breakdown
        </div>
        <div class="card-body">
            <table class="table table-bordered table-striped" id="dailyAnalyticsTable">
                <thead>
                    <tr>
                        <th>Date</th>
                        <th>Canva Revenue</th>
                        <th>Pack Revenue</th>
                        <th>Office Revenue</th>
                        <th>Total Revenue</th>
                        <th>Product Cost</th>
                        <th>FB Ads Cost</th>
                        <th>Total Cost</th>
                        <th>Profit</th>
                        <th>Profit Margin</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($daily_data as $row): ?>
                    <tr>
                        <td><?php echo date('Y-m-d', strtotime($row['date'])); ?></td>
                        <td><?php echo number_format($row['canva_revenue'], 2); ?> MAD</td>
                        <td><?php echo number_format($row['pack_revenue'], 2); ?> MAD</td>
                        <td><?php echo number_format($row['office_revenue'], 2); ?> MAD</td>
                        <td><?php echo number_format($row['canva_revenue'] + $row['pack_revenue'] + $row['office_revenue'], 2); ?> MAD</td>
                        <td><?php echo number_format($row['total_cost'], 2); ?> MAD</td>
                        <td><?php echo number_format($row['fb_ads_cost'], 2); ?> MAD</td>
                        <td><?php echo number_format($row['total_cost'] + $row['fb_ads_cost'], 2); ?> MAD</td>
                        <td><?php 
                            $daily_profit = ($row['canva_revenue'] + $row['pack_revenue'] + $row['office_revenue']) - 
                                          ($row['total_cost'] + $row['fb_ads_cost']);
                            echo number_format($daily_profit, 2); ?> MAD</td>
                        <td><?php 
                            $daily_revenue = $row['canva_revenue'] + $row['pack_revenue'] + $row['office_revenue'];
                            echo $daily_revenue > 0 ? number_format($daily_profit / $daily_revenue * 100, 1) : 0; ?>%</td>
                    </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
    </div>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    // Initialize DataTable
    $('#dailyAnalyticsTable').DataTable({
        order: [[0, 'desc']], // Sort by date descending
        pageLength: 25,
        language: {
            search: "Search daily records:",
            lengthMenu: "Show _MENU_ records per page",
            info: "Showing _START_ to _END_ of _TOTAL_ records",
            infoEmpty: "No records found",
            infoFiltered: "(filtered from _MAX_ total records)",
            zeroRecords: "No matching records found",
            paginate: {
                first: "First",
                last: "Last",
                next: "Next",
                previous: "Previous"
            }
        }
    });

    // Revenue vs Cost Chart
    const revenueCostCtx = document.getElementById('revenueCostChart').getContext('2d');
    new Chart(revenueCostCtx, {
        type: 'line',
        data: {
            labels: <?php echo json_encode($dates); ?>,
            datasets: [{
                label: 'Revenue',
                data: <?php echo json_encode($total_revenue); ?>,
                borderColor: 'rgb(75, 192, 192)',
                tension: 0.1,
                fill: false
            }, {
                label: 'Cost',
                data: <?php echo json_encode($total_cost); ?>,
                borderColor: 'rgb(255, 99, 132)',
                tension: 0.1,
                fill: false
            }]
        },
        options: {
            responsive: true,
            scales: {
                y: {
                    beginAtZero: true,
                    ticks: {
                        callback: function(value) {
                            return value.toLocaleString() + ' MAD';
                        }
                    }
                }
            }
        }
    });

    // Profit Chart
    const profitCtx = document.getElementById('profitChart').getContext('2d');
    new Chart(profitCtx, {
        type: 'bar',
        data: {
            labels: <?php echo json_encode($dates); ?>,
            datasets: [{
                label: 'Daily Profit',
                data: <?php echo json_encode($profit); ?>,
                backgroundColor: 'rgba(75, 192, 192, 0.5)',
                borderColor: 'rgb(75, 192, 192)',
                borderWidth: 1
            }]
        },
        options: {
            responsive: true,
            scales: {
                y: {
                    beginAtZero: true,
                    ticks: {
                        callback: function(value) {
                            return value.toLocaleString() + ' MAD';
                        }
                    }
                }
            }
        }
    });
});
</script>

<?php require_once 'footer.php'; ?> 