<?php
$page_title = "Facebook Ads Analysis";
$extra_css = '<script src="https://cdn.jsdelivr.net/npm/chart.js"></script>';
require_once 'header.php';
require_once 'database.php';

if (!isset($_SESSION['user_id'])) {
    header("Location: login.php");
    exit();
}

$db = new Database();
$conn = $db->connect();

// Get date range parameters
$start_date = isset($_GET['start_date']) ? $_GET['start_date'] : date('Y-m-d', strtotime('-30 days'));
$end_date = isset($_GET['end_date']) ? $_GET['end_date'] : date('Y-m-d');

try {
    // First, check if we have any data
    $check_sql = "SELECT COUNT(*) as count FROM fb_ads";
    $stmt = $conn->query($check_sql);
    $total_records = $stmt->fetch(PDO::FETCH_ASSOC)['count'];

    if ($total_records == 0) {
        $error_message = "No Facebook Ads data available. Please upload some data first.";
    } else {
        // Fetch ads data
        $sql = "SELECT 
                    DATE(date) as date,
                    COALESCE(SUM(impressions), 0) as total_impressions,
                    COALESCE(SUM(reach), 0) as total_reach,
                    COALESCE(SUM(link_clicks), 0) as total_clicks,
                    COALESCE(SUM(amount_spent), 0) as total_spent,
                    COALESCE(SUM(conversations_started), 0) as total_conversations,
                    COALESCE(AVG(cpm), 0) as avg_cpm,
                    COALESCE(AVG(ctr), 0) as avg_ctr,
                    COUNT(DISTINCT campaign_id) as campaign_count
                FROM fb_ads 
                WHERE date BETWEEN ? AND ?
                GROUP BY DATE(date)
                ORDER BY date ASC";

        $stmt = $conn->prepare($sql);
        $stmt->execute([$start_date, $end_date]);
        $daily_stats = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // Calculate overall metrics
        $sql = "SELECT 
                    COUNT(DISTINCT campaign_id) as total_campaigns,
                    COALESCE(SUM(impressions), 0) as total_impressions,
                    COALESCE(SUM(reach), 0) as total_reach,
                    COALESCE(SUM(link_clicks), 0) as total_clicks,
                    COALESCE(SUM(amount_spent), 0) as total_spent,
                    COALESCE(SUM(conversations_started), 0) as total_conversations,
                    COALESCE(AVG(cpm), 0) as avg_cpm,
                    COALESCE(AVG(ctr), 0) as avg_ctr
                FROM fb_ads 
                WHERE date BETWEEN ? AND ?";

        $stmt = $conn->prepare($sql);
        $stmt->execute([$start_date, $end_date]);
        $overall_stats = $stmt->fetch(PDO::FETCH_ASSOC);

        // Get campaign performance
        $sql = "SELECT 
                    campaign_name,
                    campaign_id,
                    COALESCE(SUM(impressions), 0) as campaign_impressions,
                    COALESCE(SUM(reach), 0) as campaign_reach,
                    COALESCE(SUM(link_clicks), 0) as campaign_clicks,
                    COALESCE(SUM(amount_spent), 0) as campaign_spent,
                    COALESCE(SUM(conversations_started), 0) as campaign_conversations,
                    COALESCE(AVG(cpm), 0) as campaign_cpm,
                    COALESCE(AVG(ctr), 0) as campaign_ctr
                FROM fb_ads 
                WHERE date BETWEEN ? AND ?
                GROUP BY campaign_id, campaign_name
                ORDER BY campaign_spent DESC";

        $stmt = $conn->prepare($sql);
        $stmt->execute([$start_date, $end_date]);
        $campaign_stats = $stmt->fetchAll(PDO::FETCH_ASSOC);
    }
} catch (PDOException $e) {
    $error_message = "Database error: " . $e->getMessage();
    error_log($error_message);
}
?>

    <?php if (isset($error_message)): ?>
        <div class="alert alert-warning">
            <?php echo htmlspecialchars($error_message); ?>
            <br>
            <a href="upload.php" class="btn btn-primary mt-2">Upload Facebook Ads Data</a>
        </div>
    <?php else: ?>
        <!-- Date Range Filter -->
        <div class="card mb-4">
            <div class="card-body">
                <form class="row g-3">
                    <div class="col-md-4">
                        <label class="form-label">Start Date</label>
                        <input type="date" class="form-control" name="start_date" value="<?php echo htmlspecialchars($start_date); ?>">
                    </div>
                    <div class="col-md-4">
                        <label class="form-label">End Date</label>
                        <input type="date" class="form-control" name="end_date" value="<?php echo htmlspecialchars($end_date); ?>">
                    </div>
                    <div class="col-md-4">
                        <label class="form-label">&nbsp;</label>
                        <button type="submit" class="btn btn-primary w-100">Apply Filter</button>
                    </div>
                </form>
            </div>
        </div>

        <!-- Overall Stats -->
        <div class="row g-4 mb-4">
            <div class="col-md-3">
                <div class="card stats-card h-100">
                    <div class="card-body">
                        <h6 class="card-title text-muted">Total Spent</h6>
                        <h3>$<?php echo number_format($overall_stats['total_spent'], 2); ?></h3>
                    </div>
                </div>
            </div>
            <div class="col-md-3">
                <div class="card stats-card h-100">
                    <div class="card-body">
                        <h6 class="card-title text-muted">Total Impressions</h6>
                        <h3><?php echo number_format($overall_stats['total_impressions']); ?></h3>
                    </div>
                </div>
            </div>
            <div class="col-md-3">
                <div class="card stats-card h-100">
                    <div class="card-body">
                        <h6 class="card-title text-muted">Total Clicks</h6>
                        <h3><?php echo number_format($overall_stats['total_clicks']); ?></h3>
                    </div>
                </div>
            </div>
            <div class="col-md-3">
                <div class="card stats-card h-100">
                    <div class="card-body">
                        <h6 class="card-title text-muted">Conversations Started</h6>
                        <h3><?php echo number_format($overall_stats['total_conversations']); ?></h3>
                    </div>
                </div>
            </div>
        </div>

        <!-- Performance Charts -->
        <div class="row g-4 mb-4">
            <div class="col-md-6">
                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title">Daily Impressions & Clicks</h5>
                        <div class="chart-container">
                            <canvas id="performanceChart"></canvas>
                        </div>
                    </div>
                </div>
            </div>
            <div class="col-md-6">
                <div class="card">
                    <div class="card-body">
                        <h5 class="card-title">Daily Spend & CPM</h5>
                        <div class="chart-container">
                            <canvas id="spendChart"></canvas>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <!-- Campaign Performance Table -->
        <div class="card">
            <div class="card-body">
                <h5 class="card-title mb-4">Campaign Performance</h5>
                <div class="table-responsive">
                    <table class="table table-hover">
                        <thead>
                            <tr>
                                <th>Campaign Name</th>
                                <th>Impressions</th>
                                <th>Clicks</th>
                                <th>CTR</th>
                                <th>Spent</th>
                                <th>CPM</th>
                                <th>Conversations</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if (empty($campaign_stats)): ?>
                                <tr>
                                    <td colspan="7" class="text-center">No campaign data available for the selected date range.</td>
                                </tr>
                            <?php else: ?>
                                <?php foreach ($campaign_stats as $campaign): ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($campaign['campaign_name']); ?></td>
                                    <td><?php echo number_format($campaign['campaign_impressions']); ?></td>
                                    <td><?php echo number_format($campaign['campaign_clicks']); ?></td>
                                    <td><?php echo number_format($campaign['campaign_ctr'] * 100, 2); ?>%</td>
                                    <td>$<?php echo number_format($campaign['campaign_spent'], 2); ?></td>
                                    <td>$<?php echo number_format($campaign['campaign_cpm'], 2); ?></td>
                                    <td><?php echo number_format($campaign['campaign_conversations']); ?></td>
                                </tr>
                                <?php endforeach; ?>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </div>

        <script>
            // Prepare data for charts
            const dates = <?php echo json_encode(array_column($daily_stats, 'date')); ?>;
            const impressions = <?php echo json_encode(array_map('intval', array_column($daily_stats, 'total_impressions'))); ?>;
            const clicks = <?php echo json_encode(array_map('intval', array_column($daily_stats, 'total_clicks'))); ?>;
            const spend = <?php echo json_encode(array_map('floatval', array_column($daily_stats, 'total_spent'))); ?>;
            const cpm = <?php echo json_encode(array_map('floatval', array_column($daily_stats, 'avg_cpm'))); ?>;

            // Performance Chart
            const performanceCtx = document.getElementById('performanceChart').getContext('2d');
            new Chart(performanceCtx, {
                type: 'line',
                data: {
                    labels: dates,
                    datasets: [
                        {
                            label: 'Impressions',
                            data: impressions,
                            borderColor: '#0d6efd',
                            yAxisID: 'y'
                        },
                        {
                            label: 'Clicks',
                            data: clicks,
                            borderColor: '#198754',
                            yAxisID: 'y1'
                        }
                    ]
                },
                options: {
                    responsive: true,
                    interaction: {
                        mode: 'index',
                        intersect: false,
                    },
                    scales: {
                        y: {
                            type: 'linear',
                            display: true,
                            position: 'left',
                        },
                        y1: {
                            type: 'linear',
                            display: true,
                            position: 'right',
                            grid: {
                                drawOnChartArea: false,
                            },
                        }
                    }
                }
            });

            // Spend Chart
            const spendCtx = document.getElementById('spendChart').getContext('2d');
            new Chart(spendCtx, {
                type: 'line',
                data: {
                    labels: dates,
                    datasets: [
                        {
                            label: 'Daily Spend ($)',
                            data: spend,
                            borderColor: '#0d6efd',
                            yAxisID: 'y'
                        },
                        {
                            label: 'CPM ($)',
                            data: cpm,
                            borderColor: '#dc3545',
                            yAxisID: 'y1'
                        }
                    ]
                },
                options: {
                    responsive: true,
                    interaction: {
                        mode: 'index',
                        intersect: false,
                    },
                    scales: {
                        y: {
                            type: 'linear',
                            display: true,
                            position: 'left',
                        },
                        y1: {
                            type: 'linear',
                            display: true,
                            position: 'right',
                            grid: {
                                drawOnChartArea: false,
                            },
                        }
                    }
                }
            });
        </script>
    <?php endif; ?>

</div> <!-- Close container from header -->

<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.1.3/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html> 