<?php
$page_title = "Order Management";
require_once 'header.php';
require_once 'database.php';

// Check if user is admin
if (!isset($_SESSION['role']) || $_SESSION['role'] !== 'admin') {
    header("Location: index.php");
    exit();
}

$db = new Database();
$conn = $db->connect();

$success_message = '';
$error_message = '';

// Function to log user activity (reused from admin.php)
function logUserActivity($user_id, $action, $details) {
    global $conn;
    $ip = $_SERVER['REMOTE_ADDR'];
    $stmt = $conn->prepare("INSERT INTO user_activity_logs (user_id, action, details, ip_address) VALUES (?, ?, ?, ?)");
    $stmt->execute([$user_id, $action, $details, $ip]);
}

// Function to log debugging information
function logDebug($message, $data = null) {
    $log_file = 'debug.log';
    $timestamp = date('Y-m-d H:i:s');
    $log_message = "[$timestamp] $message";
    if ($data !== null) {
        $log_message .= "\nData: " . print_r($data, true);
    }
    $log_message .= "\n" . str_repeat('-', 50) . "\n";
    error_log($log_message, 3, $log_file);
}

// Handle form submissions
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action'])) {
    logDebug("POST request received", $_POST);
    
    switch ($_POST['action']) {
        case 'bulk_update':
            $selected_orders = $_POST['selected_orders'] ?? [];
            $new_status = $_POST['bulk_status'] ?? '';
            
            logDebug("Bulk update initiated", [
                'selected_orders' => $selected_orders,
                'new_status' => $new_status
            ]);
            
            if (!empty($selected_orders) && !empty($new_status)) {
                $success_count = 0;
                $error_count = 0;
                $error_messages = [];
                
                foreach ($selected_orders as $order_id) {
                    logDebug("Processing order", ['order_id' => $order_id]);
                    
                    $table = '';
                    $id_field = '';
                    
                    // Determine which table to update based on order ID prefix
                    if (strpos($order_id, 'CANVA') === 0) {
                        $table = 'canva';
                        $id_field = 'id';
                    } elseif (strpos($order_id, 'PACK') === 0) {
                        $table = 'pack';
                        $id_field = 'id';
                    } elseif (strpos($order_id, 'OFFICE') === 0) {
                        $table = 'office';
                        $id_field = 'id';
                    }
                    
                    logDebug("Table determination", [
                        'order_id' => $order_id,
                        'table' => $table,
                        'id_field' => $id_field
                    ]);
                    
                    if ($table) {
                        try {
                            $sql = "UPDATE $table SET status = ? WHERE $id_field = ?";
                            logDebug("Executing SQL", [
                                'sql' => $sql,
                                'params' => [$new_status, $order_id]
                            ]);
                            
                            $stmt = $conn->prepare($sql);
                            if ($stmt->execute([$new_status, $order_id])) {
                                $success_count++;
                                logDebug("Order updated successfully", [
                                    'order_id' => $order_id,
                                    'table' => $table
                                ]);
                            } else {
                                $error_count++;
                                $error = "Failed to update order $order_id";
                                $error_messages[] = $error;
                                logDebug("Failed to update order", [
                                    'order_id' => $order_id,
                                    'error' => $error
                                ]);
                            }
                        } catch (PDOException $e) {
                            $error_count++;
                            $error = "Error updating order $order_id: " . $e->getMessage();
                            $error_messages[] = $error;
                            logDebug("Database error", [
                                'order_id' => $order_id,
                                'error' => $e->getMessage(),
                                'trace' => $e->getTraceAsString()
                            ]);
                        }
                    } else {
                        logDebug("Invalid order ID format", ['order_id' => $order_id]);
                    }
                }
                
                logDebug("Bulk update completed", [
                    'success_count' => $success_count,
                    'error_count' => $error_count,
                    'error_messages' => $error_messages
                ]);
                
                if ($success_count > 0) {
                    $success_message = "Successfully updated $success_count order(s)";
                    if ($error_count > 0) {
                        $success_message .= " ($error_count failed)";
                    }
                    $_SESSION['success_message'] = $success_message;
                }
                
                if ($error_count > 0) {
                    $_SESSION['error_message'] = "Some orders failed to update: " . implode(", ", $error_messages);
                }
                
                header("Location: orders.php");
                exit();
            } else {
                logDebug("Invalid bulk update request", [
                    'selected_orders_empty' => empty($selected_orders),
                    'new_status_empty' => empty($new_status)
                ]);
            }
            break;

        case 'update_status':
            $order_id = $_POST['order_id'];
            $table = $_POST['table'];
            $new_status = $_POST['status'];
            
            try {
                if (in_array($table, ['canva', 'pack', 'office'])) {
                    $stmt = $conn->prepare("UPDATE $table SET status = ? WHERE id = ?");
                    if ($stmt->execute([$new_status, $order_id])) {
                        logUserActivity($_SESSION['user_id'], 'update_order_status', "Updated order #$order_id status to $new_status in $table");
                        $success_message = "Order status updated successfully";
                    } else {
                        $error_message = "Failed to update order status";
                    }
                } else {
                    $error_message = "Invalid table specified";
                }
            } catch (PDOException $e) {
                $error_message = "Error updating order status: " . $e->getMessage();
            }
            break;

        case 'add_order':
            // Handle adding a new order
            $table = $_POST['table'];
            $date = $_POST['date'];
            $msg_id = $_POST['msg_id'];
            $phone = $_POST['phone'];
            $email = $_POST['email'];
            $bank = $_POST['bank'];
            $product = $_POST['product'];
            $prix = $_POST['prix'];
            $cost = $_POST['cost'];
            $status = $_POST['status'];
            $confirmed = $_POST['confirmed'];
            
            try {
                if (in_array($table, ['canva', 'pack', 'office'])) {
                    $stmt = $conn->prepare("INSERT INTO $table (date, msg_id, phone, email, bank, product, prix, cost, status, confirmed) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
                    if ($stmt->execute([$date, $msg_id, $phone, $email, $bank, $product, $prix, $cost, $status, $confirmed])) {
                        logUserActivity($_SESSION['user_id'], 'add_order', "Added new order to $table");
                        $success_message = "Order added successfully";
                    } else {
                        $error_message = "Failed to add order";
                    }
                } else {
                    $error_message = "Invalid table specified";
                }
            } catch (PDOException $e) {
                $error_message = "Error adding order: " . $e->getMessage();
            }
            break;
    }
}

// Build search conditions
$search_conditions = [];
$search_params = [];
$search_query = isset($_GET['search']) ? trim($_GET['search']) : '';
$status_filter = isset($_GET['status']) ? $_GET['status'] : '';
$source_filter = isset($_GET['source']) ? $_GET['source'] : '';
$date_from = isset($_GET['date_from']) ? $_GET['date_from'] : '';
$date_to = isset($_GET['date_to']) ? $_GET['date_to'] : '';

// Common search fields for all tables
$search_fields = "id, date, phone, email, bank, prix as amount, COALESCE(status, 'pending') as status";

// Build the UNION query with search conditions
$query = "";
$tables = ['canva', 'pack', 'office'];

foreach ($tables as $table) {
    if ($query) $query .= " UNION ALL ";
    
    $table_conditions = [];
    $query .= "SELECT '$table' as source, $search_fields FROM $table WHERE 1=1";
    
    if ($search_query) {
        $query .= " AND (
            phone LIKE ? OR 
            email LIKE ? OR 
            bank LIKE ? OR 
            CAST(id AS CHAR) LIKE ?
        )";
        $search_params = array_merge($search_params, 
            ["%$search_query%", "%$search_query%", "%$search_query%", "%$search_query%"]);
    }
    
    if ($status_filter) {
        $query .= " AND COALESCE(status, 'pending') = ?";
        $search_params[] = $status_filter;
    }
    
    if ($source_filter && $source_filter === $table) {
        $table_conditions[] = "1=1";
    }
    
    if ($date_from) {
        $query .= " AND date >= ?";
        $search_params[] = $date_from;
    }
    
    if ($date_to) {
        $query .= " AND date <= ?";
        $search_params[] = $date_to . ' 23:59:59';
    }
}

$query .= " ORDER BY date DESC";

// Execute search query
try {
    $stmt = $conn->prepare($query);
    $stmt->execute($search_params);
    $orders = $stmt->fetchAll();
} catch (PDOException $e) {
    $error_message = "Error fetching orders: " . $e->getMessage();
    $orders = [];
}
?>

<div class="container-fluid px-4">
    <h1 class="mt-4">Order Management</h1>
    
    <?php if ($success_message): ?>
        <div class="alert alert-success alert-dismissible fade show" role="alert">
            <?php echo htmlspecialchars($success_message); ?>
            <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
        </div>
    <?php endif; ?>

    <?php if ($error_message): ?>
        <div class="alert alert-danger alert-dismissible fade show" role="alert">
            <?php echo htmlspecialchars($error_message); ?>
            <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
        </div>
    <?php endif; ?>

    <!-- Search Form -->
    <div class="card mb-4">
        <div class="card-body">
            <form method="GET" class="row g-3">
                <div class="col-md-3">
                    <label class="form-label">Search</label>
                    <input type="text" name="search" class="form-control" placeholder="Search orders..." value="<?php echo htmlspecialchars($search_query); ?>">
                </div>
                <div class="col-md-2">
                    <label class="form-label">Status</label>
                    <select name="status" class="form-select">
                        <option value="">All Statuses</option>
                        <option value="pending" <?php echo $status_filter === 'pending' ? 'selected' : ''; ?>>Pending</option>
                        <option value="processing" <?php echo $status_filter === 'processing' ? 'selected' : ''; ?>>Processing</option>
                        <option value="completed" <?php echo $status_filter === 'completed' ? 'selected' : ''; ?>>Completed</option>
                        <option value="cancelled" <?php echo $status_filter === 'cancelled' ? 'selected' : ''; ?>>Cancelled</option>
                    </select>
                </div>
                <div class="col-md-2">
                    <label class="form-label">Source</label>
                    <select name="source" class="form-select">
                        <option value="">All Sources</option>
                        <option value="canva" <?php echo $source_filter === 'canva' ? 'selected' : ''; ?>>Canva</option>
                        <option value="pack" <?php echo $source_filter === 'pack' ? 'selected' : ''; ?>>Pack</option>
                        <option value="office" <?php echo $source_filter === 'office' ? 'selected' : ''; ?>>Office</option>
                    </select>
                </div>
                <div class="col-md-2">
                    <label class="form-label">Date From</label>
                    <input type="date" name="date_from" class="form-control" value="<?php echo $date_from; ?>">
                </div>
                <div class="col-md-2">
                    <label class="form-label">Date To</label>
                    <input type="date" name="date_to" class="form-control" value="<?php echo $date_to; ?>">
                </div>
                <div class="col-md-1">
                    <label class="form-label">&nbsp;</label>
                    <button type="submit" class="btn btn-primary w-100">Search</button>
                </div>
            </form>
        </div>
    </div>

    <!-- Add New Order Button -->
    <div class="mb-4">
        <button type="button" class="btn btn-primary" data-bs-toggle="modal" data-bs-target="#addOrderModal">
            <i class="bx bx-plus"></i> Add New Order
        </button>
    </div>

    <!-- Add Order Modal -->
    <div class="modal fade" id="addOrderModal" tabindex="-1">
        <div class="modal-dialog modal-lg">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">Add New Order</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <form method="POST" id="addOrderForm">
                    <div class="modal-body">
                        <input type="hidden" name="action" value="add_order">
                        
                        <div class="row g-3">
                            <div class="col-md-6">
                                <label class="form-label">Order Type</label>
                                <select name="table" class="form-select" required>
                                    <option value="canva">Canva</option>
                                    <option value="pack">Pack</option>
                                    <option value="office">Office</option>
                                </select>
                            </div>
                            
                            <div class="col-md-6">
                                <label class="form-label">Date</label>
                                <input type="date" name="date" class="form-control" value="<?php echo date('Y-m-d'); ?>" required>
                            </div>

                            <div class="col-md-6">
                                <label class="form-label">WhatsApp</label>
                                <input type="text" name="phone" class="form-control" required>
                            </div>

                            <div class="col-md-6">
                                <label class="form-label">Email</label>
                                <input type="email" name="email" class="form-control" required>
                            </div>

                            <div class="col-md-6">
                                <label class="form-label">Bank</label>
                                <input type="text" name="bank" class="form-control" required>
                            </div>

                            <div class="col-md-6">
                                <label class="form-label">Price</label>
                                <input type="number" name="prix" class="form-control" step="0.01" required>
                            </div>

                            <div class="col-md-6">
                                <label class="form-label">Cost</label>
                                <input type="number" name="cost" class="form-control" step="0.01" value="0.00" required>
                            </div>

                            <div class="col-md-6">
                                <label class="form-label">Status</label>
                                <select name="status" class="form-select" required>
                                    <option value="pending">Pending</option>
                                    <option value="processing">Processing</option>
                                    <option value="completed">Completed</option>
                                    <option value="cancelled">Cancelled</option>
                                </select>
                            </div>
                        </div>
                    </div>
                    <div class="modal-footer">
                        <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                        <button type="submit" class="btn btn-primary">Add Order</button>
                    </div>
                </form>
            </div>
        </div>
    </div>

    <!-- Orders Table -->
    <div class="card mb-4">
        <div class="card-body">
            <form method="POST" id="ordersForm">
                <input type="hidden" name="action" value="bulk_update">
                
                <!-- Bulk Actions -->
                <div class="row mb-3">
                    <div class="col-auto">
                        <select name="bulk_status" class="form-select" required>
                            <option value="">Bulk Update Status</option>
                            <option value="pending">Pending</option>
                            <option value="processing">Processing</option>
                            <option value="completed">Completed</option>
                            <option value="cancelled">Cancelled</option>
                        </select>
                    </div>
                    <div class="col-auto">
                        <button type="submit" class="btn btn-warning" id="bulkUpdateBtn" disabled>Update Selected Orders</button>
                    </div>
                </div>

                <div class="table-responsive">
                    <table class="table table-bordered table-striped" id="ordersTable">
                        <thead>
                            <tr>
                                <th>
                                    <input type="checkbox" id="selectAll" class="form-check-input">
                                </th>
                                <th>Date</th>
                                <th>Order ID</th>
                                <th>Source</th>
                                <th>Phone</th>
                                <th>Email</th>
                                <th>Bank</th>
                                <th>Amount</th>
                                <th>Status</th>
                                <th>Actions</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($orders as $order): ?>
                            <tr>
                                <td>
                                    <input type="checkbox" name="selected_orders[]" value="<?php echo htmlspecialchars($order['source'] . ':' . $order['id']); ?>" class="form-check-input order-checkbox">
                                </td>
                                <td><?php echo date('Y-m-d', strtotime($order['date'])); ?></td>
                                <td>#<?php echo $order['id']; ?></td>
                                <td><?php echo ucfirst($order['source']); ?></td>
                                <td><?php echo htmlspecialchars($order['phone']); ?></td>
                                <td><?php echo htmlspecialchars($order['email']); ?></td>
                                <td><?php echo htmlspecialchars($order['bank']); ?></td>
                                <td>$<?php echo number_format($order['amount'], 2); ?></td>
                                <td>
                                    <span class="badge bg-<?php 
                                        echo $order['status'] === 'completed' ? 'success' : 
                                            ($order['status'] === 'pending' ? 'warning' : 
                                            ($order['status'] === 'cancelled' ? 'danger' : 'info')); 
                                    ?>">
                                        <?php echo ucfirst($order['status']); ?>
                                    </span>
                                </td>
                                <td>
                                    <form method="POST" style="display: inline;">
                                        <input type="hidden" name="action" value="update_status">
                                        <input type="hidden" name="order_id" value="<?php echo $order['id']; ?>">
                                        <input type="hidden" name="table" value="<?php echo $order['source']; ?>">
                                        <select name="status" class="form-select form-select-sm d-inline-block w-auto" onchange="this.form.submit()">
                                            <option value="pending" <?php echo $order['status'] === 'pending' ? 'selected' : ''; ?>>Pending</option>
                                            <option value="processing" <?php echo $order['status'] === 'processing' ? 'selected' : ''; ?>>Processing</option>
                                            <option value="completed" <?php echo $order['status'] === 'completed' ? 'selected' : ''; ?>>Completed</option>
                                            <option value="cancelled" <?php echo $order['status'] === 'cancelled' ? 'selected' : ''; ?>>Cancelled</option>
                                        </select>
                                    </form>
                                </td>
                            </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            </form>
        </div>
    </div>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    const selectAll = document.getElementById('selectAll');
    const orderCheckboxes = document.querySelectorAll('.order-checkbox');
    const bulkUpdateBtn = document.getElementById('bulkUpdateBtn');
    const ordersForm = document.getElementById('ordersForm');

    // Initialize DataTable after ensuring jQuery and DataTables are loaded
    if (typeof jQuery !== 'undefined' && typeof jQuery.fn.DataTable !== 'undefined') {
        $('#ordersTable').DataTable({
            order: [[1, 'desc']], // Sort by date column by default
            pageLength: 25,
            language: {
                search: "Search orders:",
                lengthMenu: "Show _MENU_ orders per page",
                info: "Showing _START_ to _END_ of _TOTAL_ orders",
                infoEmpty: "No orders found",
                infoFiltered: "(filtered from _MAX_ total orders)",
                zeroRecords: "No matching orders found",
                paginate: {
                    first: "First",
                    last: "Last",
                    next: "Next",
                    previous: "Previous"
                }
            }
        });
    }

    // Handle select all checkbox
    if (selectAll) {
        selectAll.addEventListener('change', function() {
            orderCheckboxes.forEach(checkbox => {
                checkbox.checked = this.checked;
            });
            updateBulkButtonState();
        });
    }

    // Handle individual checkboxes
    orderCheckboxes.forEach(checkbox => {
        checkbox.addEventListener('change', function() {
            updateBulkButtonState();
            updateSelectAllState();
        });
    });

    // Update bulk update button state
    function updateBulkButtonState() {
        const checkedBoxes = document.querySelectorAll('.order-checkbox:checked');
        const bulkStatus = document.querySelector('select[name="bulk_status"]').value;
        if (bulkUpdateBtn) {
            bulkUpdateBtn.disabled = checkedBoxes.length === 0 || !bulkStatus;
        }
    }

    // Update select all checkbox state
    function updateSelectAllState() {
        if (selectAll) {
            const allChecked = Array.from(orderCheckboxes).every(checkbox => checkbox.checked);
            const someChecked = Array.from(orderCheckboxes).some(checkbox => checkbox.checked);
            selectAll.checked = allChecked;
            selectAll.indeterminate = someChecked && !allChecked;
        }
    }

    // Handle bulk status change
    const bulkStatusSelect = document.querySelector('select[name="bulk_status"]');
    if (bulkStatusSelect) {
        bulkStatusSelect.addEventListener('change', updateBulkButtonState);
    }

    // Handle form submission
    if (ordersForm) {
        ordersForm.addEventListener('submit', function(e) {
            e.preventDefault();
            
            const checkedBoxes = document.querySelectorAll('.order-checkbox:checked');
            const bulkStatus = document.querySelector('select[name="bulk_status"]').value;
            
            if (!bulkStatus) {
                alert('Please select a status for bulk update');
                return;
            }
            
            if (!confirm(`Are you sure you want to update ${checkedBoxes.length} orders to "${bulkStatus}" status?`)) {
                return;
            }

            // Show loading state
            const submitBtn = this.querySelector('button[type="submit"]');
            const originalText = submitBtn.innerHTML;
            submitBtn.innerHTML = '<span class="spinner-border spinner-border-sm" role="status" aria-hidden="true"></span> Updating...';
            submitBtn.disabled = true;

            // Submit the form
            const formData = new FormData(this);
            fetch(window.location.href, {
                method: 'POST',
                body: formData
            })
            .then(response => {
                if (!response.ok) {
                    throw new Error('Network response was not ok');
                }
                return response.text();
            })
            .then(html => {
                if (html.includes('error_message')) {
                    throw new Error('Server returned an error');
                }
                window.location.reload();
            })
            .catch(error => {
                console.error('Error:', error);
                alert('An error occurred while updating orders. Please try again.');
            })
            .finally(() => {
                submitBtn.innerHTML = originalText;
                submitBtn.disabled = false;
            });
        });
    }

    // Handle add order form
    const addOrderForm = document.getElementById('addOrderForm');
    if (addOrderForm) {
        addOrderForm.addEventListener('submit', function(e) {
            e.preventDefault();
            const formData = new FormData(this);
            
            const submitBtn = this.querySelector('button[type="submit"]');
            const originalText = submitBtn.innerHTML;
            submitBtn.innerHTML = '<span class="spinner-border spinner-border-sm" role="status" aria-hidden="true"></span> Adding...';
            submitBtn.disabled = true;

            fetch(window.location.href, {
                method: 'POST',
                body: formData
            })
            .then(response => {
                if (!response.ok) {
                    throw new Error('Network response was not ok');
                }
                return response.text();
            })
            .then(html => {
                if (html.includes('error_message')) {
                    throw new Error('Server returned an error');
                }
                window.location.reload();
            })
            .catch(error => {
                console.error('Error:', error);
                alert('An error occurred while adding the order. Please try again.');
            })
            .finally(() => {
                submitBtn.innerHTML = originalText;
                submitBtn.disabled = false;
            });
        });
    }
});
</script>

<?php require_once 'footer.php'; ?> 