<?php
require_once 'header.php';
require_once 'database.php';

// Check if user is admin
if (!isset($_SESSION['role']) || $_SESSION['role'] !== 'admin') {
    header("Location: index.php");
    exit();
}

$db = new Database();
$conn = $db->connect();

$success_message = '';
$error_message = '';

// Function to log debugging information
function logDebug($message, $data = null) {
    $log_file = 'debug.log';
    $timestamp = date('Y-m-d H:i:s');
    $log_message = "[$timestamp] $message";
    if ($data !== null) {
        $log_message .= "\nData: " . print_r($data, true);
    }
    $log_message .= "\n" . str_repeat('-', 50) . "\n";
    error_log($log_message, 3, $log_file);
}

if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['action']) && $_POST['action'] === 'update_all') {
    try {
        $conn->beginTransaction();
        
        $tables = ['canva', 'pack', 'office'];
        $total_updated = 0;
        $errors = [];
        
        foreach ($tables as $table) {
            logDebug("Updating orders in table", ['table' => $table]);
            
            $stmt = $conn->prepare("UPDATE $table SET status = 'completed' WHERE status != 'completed'");
            $result = $stmt->execute();
            
            if ($result) {
                $updated_count = $stmt->rowCount();
                $total_updated += $updated_count;
                logDebug("Updated orders in table", [
                    'table' => $table,
                    'updated_count' => $updated_count
                ]);
            } else {
                $errors[] = "Failed to update orders in $table table";
                logDebug("Failed to update orders in table", [
                    'table' => $table,
                    'error' => $stmt->errorInfo()
                ]);
            }
        }
        
        if ($total_updated > 0) {
            $conn->commit();
            $success_message = "Successfully updated $total_updated orders to completed status";
            logDebug("Bulk update completed", [
                'total_updated' => $total_updated,
                'errors' => $errors
            ]);
        } else {
            $conn->rollBack();
            $error_message = "No orders were updated";
            logDebug("No orders were updated", ['errors' => $errors]);
        }
        
    } catch (PDOException $e) {
        $conn->rollBack();
        $error_message = "Error updating orders: " . $e->getMessage();
        logDebug("Database error", [
            'error' => $e->getMessage(),
            'trace' => $e->getTraceAsString()
        ]);
    }
}
?>

<div class="container-fluid px-4">
    <h1 class="mt-4">Update All Orders Status</h1>
    
    <?php if ($success_message): ?>
        <div class="alert alert-success alert-dismissible fade show" role="alert">
            <?php echo htmlspecialchars($success_message); ?>
            <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
        </div>
    <?php endif; ?>

    <?php if ($error_message): ?>
        <div class="alert alert-danger alert-dismissible fade show" role="alert">
            <?php echo htmlspecialchars($error_message); ?>
            <button type="button" class="btn-close" data-bs-dismiss="alert"></button>
        </div>
    <?php endif; ?>

    <div class="card mb-4">
        <div class="card-body">
            <div class="alert alert-warning">
                <h5 class="alert-heading">Warning!</h5>
                <p>This action will update all non-completed orders to completed status. This action cannot be undone.</p>
            </div>
            
            <form method="POST" id="updateAllForm">
                <input type="hidden" name="action" value="update_all">
                <button type="submit" class="btn btn-warning" id="updateAllBtn">
                    Update All Orders to Completed
                </button>
            </form>
        </div>
    </div>
</div>

<script>
document.addEventListener('DOMContentLoaded', function() {
    const updateAllForm = document.getElementById('updateAllForm');
    const updateAllBtn = document.getElementById('updateAllBtn');
    
    if (updateAllForm) {
        updateAllForm.addEventListener('submit', function(e) {
            e.preventDefault();
            
            if (!confirm('Are you sure you want to update all non-completed orders to completed status? This action cannot be undone.')) {
                return;
            }
            
            // Show loading state
            const originalText = updateAllBtn.innerHTML;
            updateAllBtn.innerHTML = '<span class="spinner-border spinner-border-sm" role="status" aria-hidden="true"></span> Updating...';
            updateAllBtn.disabled = true;
            
            // Submit the form
            const formData = new FormData(this);
            fetch(window.location.href, {
                method: 'POST',
                body: formData
            })
            .then(response => {
                if (!response.ok) {
                    throw new Error('Network response was not ok');
                }
                return response.text();
            })
            .then(html => {
                if (html.includes('error_message')) {
                    throw new Error('Server returned an error');
                }
                window.location.reload();
            })
            .catch(error => {
                console.error('Error:', error);
                alert('An error occurred while updating orders. Please try again.');
            })
            .finally(() => {
                updateAllBtn.innerHTML = originalText;
                updateAllBtn.disabled = false;
            });
        });
    }
});
</script>

<?php require_once 'footer.php'; ?> 